Token

Struct Token 

pub struct Token {
    pub audit_ids: Vec<String>,
    pub methods: Vec<String>,
    pub expires_at: DateTime<Utc>,
    pub issued_at: DateTime<Utc>,
    pub user: User,
    pub domain: Option<Domain>,
    pub project: Option<Project>,
    pub trust: Option<TokenTrustRepr>,
    pub roles: Option<Vec<RoleRef>>,
    pub system: Option<System>,
    pub catalog: Option<Catalog>,
}
Authorization token.

Fields

audit_ids: Vec<String>

A list of one or two audit IDs. An audit ID is a unique, randomly generated, URL-safe string that you can use to track a token. The first audit ID is the current audit ID for the token. The second audit ID is present for only re-scoped tokens and is the audit ID from the token before it was re-scoped. A re- scoped token is one that was exchanged for another token of the same or different scope. You can use these audit IDs to track the use of a token or chain of tokens across multiple requests and endpoints without exposing the token ID to non-privileged users.

methods: Vec<String>

The authentication methods, which are commonly password, token, or other methods. Indicates the accumulated set of authentication methods that were used to obtain the token. For example, if the token was obtained by password authentication, it contains password. Later, if the token is exchanged by using the token authentication method one or more times, the subsequently created tokens contain both password and token in their methods attribute. Unlike multi-factor authentication, the methods attribute merely indicates the methods that were used to authenticate the user in exchange for a token. The client is responsible for determining the total number of authentication factors.

expires_at: DateTime<Utc>

The date and time when the token expires.

issued_at: DateTime<Utc>

The date and time when the token was issued.

user: User

A user object.

domain: Option<Domain>

A domain object including the id and name representing the domain the token is scoped to. This is only included in tokens that are scoped to a domain.

project: Option<Project>

A project object including the id, name and domain object representing the project the token is scoped to. This is only included in tokens that are scoped to a project.

trust: Option<TokenTrustRepr>

A trust object.

roles: Option<Vec<RoleRef>>

A list of role objects.

system: Option<System>

A system object.

catalog: Option<Catalog>

A catalog object.