pub struct Project {
pub description: Option<String>,
pub domain_id: String,
pub enabled: bool,
pub extra: Option<Value>,
pub id: String,
pub is_domain: bool,
pub name: String,
pub parent_id: Option<String>,
}Expand description
Full project representation.
Fields
description: Option<String>The description of the project.
domain_id: StringThe ID of the domain for the project.
enabled: boolIf set to true, project is enabled. If set to false, project is disabled.
extra: Option<Value>Additional project properties.
id: StringThe ID for the project.
is_domain: boolIndicates whether the project also acts as a domain. If set to true, this project acts as both a project and domain. As a domain, the project provides a name space in which you can create users, groups, and other projects. If set to false, this project behaves as a regular project that contains only resources.
name: StringThe name of the project.
parent_id: Option<String>The ID of the parent for the project.