pub struct ProjectBuilder { /* private fields */ }Expand description
Builder for Project.
Implementations
Sourceimpl ProjectBuilder
impl ProjectBuilder
Sourcepub fn description<VALUE>(&mut self, value: VALUE) -> &mut ProjectBuilder
pub fn description<VALUE>(&mut self, value: VALUE) -> &mut ProjectBuilder
The description of the project.
Sourcepub fn domain_id<VALUE>(&mut self, value: VALUE) -> &mut ProjectBuilder
pub fn domain_id<VALUE>(&mut self, value: VALUE) -> &mut ProjectBuilder
The ID of the domain for the project.
Sourcepub fn enabled<VALUE>(&mut self, value: VALUE) -> &mut ProjectBuilder
pub fn enabled<VALUE>(&mut self, value: VALUE) -> &mut ProjectBuilder
If set to true, project is enabled. If set to false, project is disabled.
Sourcepub fn extra<VALUE>(&mut self, value: VALUE) -> &mut ProjectBuilder
pub fn extra<VALUE>(&mut self, value: VALUE) -> &mut ProjectBuilder
Additional project properties.
Sourcepub fn id<VALUE>(&mut self, value: VALUE) -> &mut ProjectBuilder
pub fn id<VALUE>(&mut self, value: VALUE) -> &mut ProjectBuilder
The ID for the project.
Sourcepub fn is_domain<VALUE>(&mut self, value: VALUE) -> &mut ProjectBuilder
pub fn is_domain<VALUE>(&mut self, value: VALUE) -> &mut ProjectBuilder
Indicates whether the project also acts as a domain. If set to true, this project acts as both a project and domain. As a domain, the project provides a name space in which you can create users, groups, and other projects. If set to false, this project behaves as a regular project that contains only resources.
Sourcepub fn name<VALUE>(&mut self, value: VALUE) -> &mut ProjectBuilder
pub fn name<VALUE>(&mut self, value: VALUE) -> &mut ProjectBuilder
The name of the project.
Sourcepub fn parent_id<VALUE>(&mut self, value: VALUE) -> &mut ProjectBuilder
pub fn parent_id<VALUE>(&mut self, value: VALUE) -> &mut ProjectBuilder
The ID of the parent for the project.