pub struct ProjectCreate {
pub description: Option<String>,
pub domain_id: String,
pub enabled: bool,
pub extra: Option<Value>,
pub is_domain: bool,
pub name: String,
pub parent_id: Option<String>,
}Expand description
New project data.
Fields
description: Option<String>The description of the project.
domain_id: StringThe ID of the domain for the project.
enabled: boolIf set to true, project is enabled. If set to false, project is
disabled. The defaults is true.
extra: Option<Value>Additional project properties.
is_domain: boolIndicates whether the project also acts as a domain. If set to true, this project acts as both a project and domain. As a domain, the project provides a name space in which you can create users, groups, and other projects. If set to false, this project behaves as a regular project that contains only resources. Default is false. You cannot update this parameter after you create the project.
name: StringThe name of the project, which must be unique within the owning domain. A project can have the same name as its domain.
parent_id: Option<String>The ID of the parent of the project.
If specified on project creation, this places the project within a
hierarchy and implicitly defines the owning domain, which will be the
same domain as the parent specified. If parent_id is not specified and
is_domain is false, then the project will use its owning domain as its
parent. If is_domain is true (i.e. the project is acting as a domain),
then parent_id must not specified (or if it is, it must be null) since
domains have no parents.
parent_id is immutable, and can’t be updated after the project is
created - hence a project cannot be moved within the hierarchy.