pub struct ProjectCreateBuilder { /* private fields */ }Expand description
Builder for ProjectCreate.
Implementations
Sourceimpl ProjectCreateBuilder
impl ProjectCreateBuilder
Sourcepub fn description<VALUE>(&mut self, value: VALUE) -> &mut ProjectCreateBuilder
pub fn description<VALUE>(&mut self, value: VALUE) -> &mut ProjectCreateBuilder
The description of the project.
Sourcepub fn domain_id<VALUE>(&mut self, value: VALUE) -> &mut ProjectCreateBuilder
pub fn domain_id<VALUE>(&mut self, value: VALUE) -> &mut ProjectCreateBuilder
The ID of the domain for the project.
Sourcepub fn enabled<VALUE>(&mut self, value: VALUE) -> &mut ProjectCreateBuilder
pub fn enabled<VALUE>(&mut self, value: VALUE) -> &mut ProjectCreateBuilder
If set to true, project is enabled. If set to false, project is
disabled. The defaults is true.
Sourcepub fn extra<VALUE>(&mut self, value: VALUE) -> &mut ProjectCreateBuilder
pub fn extra<VALUE>(&mut self, value: VALUE) -> &mut ProjectCreateBuilder
Additional project properties.
Sourcepub fn is_domain<VALUE>(&mut self, value: VALUE) -> &mut ProjectCreateBuilder
pub fn is_domain<VALUE>(&mut self, value: VALUE) -> &mut ProjectCreateBuilder
Indicates whether the project also acts as a domain. If set to true, this project acts as both a project and domain. As a domain, the project provides a name space in which you can create users, groups, and other projects. If set to false, this project behaves as a regular project that contains only resources. Default is false. You cannot update this parameter after you create the project.
Sourcepub fn name<VALUE>(&mut self, value: VALUE) -> &mut ProjectCreateBuilder
pub fn name<VALUE>(&mut self, value: VALUE) -> &mut ProjectCreateBuilder
The name of the project, which must be unique within the owning domain. A project can have the same name as its domain.
Sourcepub fn parent_id<VALUE>(&mut self, value: VALUE) -> &mut ProjectCreateBuilder
pub fn parent_id<VALUE>(&mut self, value: VALUE) -> &mut ProjectCreateBuilder
The ID of the parent of the project.
If specified on project creation, this places the project within a
hierarchy and implicitly defines the owning domain, which will be the
same domain as the parent specified. If parent_id is not specified and
is_domain is false, then the project will use its owning domain as its
parent. If is_domain is true (i.e. the project is acting as a domain),
then parent_id must not specified (or if it is, it must be null) since
domains have no parents.
parent_id is immutable, and can’t be updated after the project is
created - hence a project cannot be moved within the hierarchy.
Sourcepub fn build(&self) -> Result<ProjectCreate, BuilderError>
pub fn build(&self) -> Result<ProjectCreate, BuilderError>