UserBuilder

Struct UserBuilder 

pub struct UserBuilder { /* private fields */ }
Builder for User.

Implementations

Source

impl UserBuilder

pub fn default_project_id<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
where VALUE: Into<String>,

The ID of the default project for the user. A user’s default project must not be a domain. Setting this attribute does not grant any actual authorization on the project, and is merely provided for convenience. Therefore, the referenced project does not need to exist within the user domain. If the user does not have authorization to their default project, the default project is ignored at token creation. Additionally, if your default project is not valid, a token is issued without an explicit scope of authorization.

pub fn domain_id<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
where VALUE: Into<String>,

User domain ID.

pub fn enabled<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
where VALUE: Into<bool>,

If the user is enabled, this value is true. If the user is disabled, this value is false.

pub fn extra<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
where VALUE: Into<Value>,

pub fn federated<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
where VALUE: Into<Vec<Federation>>,

List of federated objects associated with a user. Each object in the list contains the idp_id and protocols. protocols is a list of objects, each of which contains protocol_id and unique_id of the protocol and user respectively.

pub fn id<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
where VALUE: Into<String>,

User ID.

pub fn name<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
where VALUE: Into<String>,

User name.

pub fn options<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
where VALUE: Into<UserOptions>,

The resource options for the user. Available resource options are ignore_change_password_upon_first_use, ignore_password_expiry, ignore_lockout_failure_attempts, lock_password, multi_factor_auth_enabled, and multi_factor_auth_rules ignore_user_inactivity.

pub fn password_expires_at<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
where VALUE: Into<DateTime<Utc>>,

The date and time when the password expires. The time zone is UTC.

pub fn build(&self) -> Result<User, BuilderError>

Builds a new User.

Errors

If a required field has not been initialized.