UserCreateBuilder

Struct UserCreateBuilder 

pub struct UserCreateBuilder { /* private fields */ }
Builder for UserCreate.

Implementations

Source

impl UserCreateBuilder

pub fn default_project_id<VALUE>( &mut self, value: VALUE, ) -> &mut UserCreateBuilder
where VALUE: Into<String>,

The ID of the default project for the user. A user’s default project must not be a domain. Setting this attribute does not grant any actual authorization on the project, and is merely provided for convenience. Therefore, the referenced project does not need to exist within the user domain. If the user does not have authorization to their default project, the default project is ignored at token creation. Additionally, if your default project is not valid, a token is issued without an explicit scope of authorization.

pub fn domain_id<VALUE>(&mut self, value: VALUE) -> &mut UserCreateBuilder
where VALUE: Into<String>,

User domain ID.

pub fn enabled<VALUE>(&mut self, value: VALUE) -> &mut UserCreateBuilder
where VALUE: Into<bool>,

If the user is enabled, this value is true. If the user is disabled, this value is false.

pub fn extra<VALUE>(&mut self, value: VALUE) -> &mut UserCreateBuilder
where VALUE: Into<Value>,

Additional user properties.

pub fn name<VALUE>(&mut self, value: VALUE) -> &mut UserCreateBuilder
where VALUE: Into<String>,

The user name. Must be unique within the owning domain.

pub fn options<VALUE>(&mut self, value: VALUE) -> &mut UserCreateBuilder
where VALUE: Into<UserOptions>,

The resource options for the user. Available resource options are ignore_change_password_upon_first_use, ignore_password_expiry, ignore_lockout_failure_attempts, lock_password, multi_factor_auth_enabled, and multi_factor_auth_rules ignore_user_inactivity.

pub fn password<VALUE>(&mut self, value: VALUE) -> &mut UserCreateBuilder
where VALUE: Into<String>,

The password for the user.

pub fn build(&self) -> Result<UserCreate, BuilderError>

Builds a new UserCreate.

Errors

If a required field has not been initialized.