pub struct UserUpdateBuilder { /* private fields */ }Expand description
Builder for UserUpdate.
Implementations
Sourceimpl UserUpdateBuilder
impl UserUpdateBuilder
Sourcepub fn default_project_id<VALUE>(
&mut self,
value: VALUE,
) -> &mut UserUpdateBuilder
pub fn default_project_id<VALUE>( &mut self, value: VALUE, ) -> &mut UserUpdateBuilder
The ID of the default project for the user. A user’s default project must not be a domain. Setting this attribute does not grant any actual authorization on the project, and is merely provided for convenience. Therefore, the referenced project does not need to exist within the user domain. If the user does not have authorization to their default project, the default project is ignored at token creation. Additionally, if your default project is not valid, a token is issued without an explicit scope of authorization.
Sourcepub fn enabled<VALUE>(&mut self, value: VALUE) -> &mut UserUpdateBuilder
pub fn enabled<VALUE>(&mut self, value: VALUE) -> &mut UserUpdateBuilder
If the user is enabled, this value is true. If the user is disabled, this value is false.
Sourcepub fn extra<VALUE>(&mut self, value: VALUE) -> &mut UserUpdateBuilder
pub fn extra<VALUE>(&mut self, value: VALUE) -> &mut UserUpdateBuilder
Additional user properties.
Sourcepub fn name<VALUE>(&mut self, value: VALUE) -> &mut UserUpdateBuilder
pub fn name<VALUE>(&mut self, value: VALUE) -> &mut UserUpdateBuilder
The user name. Must be unique within the owning domain.
Sourcepub fn options<VALUE>(&mut self, value: VALUE) -> &mut UserUpdateBuilderwhere
VALUE: Into<UserOptions>,
pub fn options<VALUE>(&mut self, value: VALUE) -> &mut UserUpdateBuilderwhere
VALUE: Into<UserOptions>,
The resource options for the user. Available resource options are ignore_change_password_upon_first_use, ignore_password_expiry, ignore_lockout_failure_attempts, lock_password, multi_factor_auth_enabled, and multi_factor_auth_rules ignore_user_inactivity.
Sourcepub fn password<VALUE>(&mut self, value: VALUE) -> &mut UserUpdateBuilder
pub fn password<VALUE>(&mut self, value: VALUE) -> &mut UserUpdateBuilder
The password for the user.
Sourcepub fn build(&self) -> Result<UserUpdate, BuilderError>
pub fn build(&self) -> Result<UserUpdate, BuilderError>