TokenBuilder

Struct TokenBuilder 

pub struct TokenBuilder { /* private fields */ }
Builder for Token.

Implementations

Source

impl TokenBuilder

pub fn audit_ids<VALUE>(&mut self, value: VALUE) -> &mut TokenBuilder
where VALUE: Into<Vec<String>>,

A list of one or two audit IDs. An audit ID is a unique, randomly generated, URL-safe string that you can use to track a token. The first audit ID is the current audit ID for the token. The second audit ID is present for only re-scoped tokens and is the audit ID from the token before it was re-scoped. A re- scoped token is one that was exchanged for another token of the same or different scope. You can use these audit IDs to track the use of a token or chain of tokens across multiple requests and endpoints without exposing the token ID to non-privileged users.

pub fn methods<VALUE>(&mut self, value: VALUE) -> &mut TokenBuilder
where VALUE: Into<Vec<String>>,

The authentication methods, which are commonly password, token, or other methods. Indicates the accumulated set of authentication methods that were used to obtain the token. For example, if the token was obtained by password authentication, it contains password. Later, if the token is exchanged by using the token authentication method one or more times, the subsequently created tokens contain both password and token in their methods attribute. Unlike multi-factor authentication, the methods attribute merely indicates the methods that were used to authenticate the user in exchange for a token. The client is responsible for determining the total number of authentication factors.

pub fn expires_at<VALUE>(&mut self, value: VALUE) -> &mut TokenBuilder
where VALUE: Into<DateTime<Utc>>,

The date and time when the token expires.

pub fn issued_at<VALUE>(&mut self, value: VALUE) -> &mut TokenBuilder
where VALUE: Into<DateTime<Utc>>,

The date and time when the token was issued.

pub fn user<VALUE>(&mut self, value: VALUE) -> &mut TokenBuilder
where VALUE: Into<User>,

A user object.

pub fn domain<VALUE>(&mut self, value: VALUE) -> &mut TokenBuilder
where VALUE: Into<Domain>,

A domain object including the id and name representing the domain the token is scoped to. This is only included in tokens that are scoped to a domain.

pub fn project<VALUE>(&mut self, value: VALUE) -> &mut TokenBuilder
where VALUE: Into<Project>,

A project object including the id, name and domain object representing the project the token is scoped to. This is only included in tokens that are scoped to a project.

pub fn system<VALUE>(&mut self, value: VALUE) -> &mut TokenBuilder
where VALUE: Into<System>,

A system object.

pub fn trust<VALUE>(&mut self, value: VALUE) -> &mut TokenBuilder
where VALUE: Into<TokenTrustRepr>,

A trust object.

pub fn roles<VALUE>(&mut self, value: VALUE) -> &mut TokenBuilder
where VALUE: Into<Vec<RoleRef>>,

A list of role objects.

pub fn catalog<VALUE>(&mut self, value: VALUE) -> &mut TokenBuilder
where VALUE: Into<Catalog>,

A catalog object.

pub fn build(&self) -> Result<Token, BuilderError>

Builds a new Token.

Errors

If a required field has not been initialized.