Authorization and authentication information.
Authentication and authorization types with corresponding validation. Authentication specific validation may stay in the corresponding provider (i.e. user password is expired), but general validation rules must be present here to be shared across different authentication methods. The same is valid for the authorization validation (project/domain must exist and be enabled).
Structs
- Authenticated
Info - Information about successful authentication.
- Authenticated
Info Builder - Builder for
AuthenticatedInfo.
Enums
- Authentication
Error - Authz
Info - Authorization information.