Module plugin_manager

Module plugin_manager 

Plugin manager

A driver, also known as a backend, is an important architectural component of Keystone. It is an abstraction around the data access needed by a particular subsystem. This pluggable implementation is not only how Keystone implements its own data access, but how you can implement your own!

The PluginManagerApi is responsible for picking the proper backend driver for the provider.

Traits

PluginManagerApi
Plugin manager trait.