pub struct PolicyEvaluationResult {
pub allow: bool,
pub can_see_other_domain_resources: Option<bool>,
pub violations: Option<Vec<Violation>>,
}Expand description
The result of a policy evaluation.
Fields
allow: boolWhether the user is allowed to perform the request or not.
can_see_other_domain_resources: Option<bool>Whether the user is allowed to see resources of other domains.
violations: Option<Vec<Violation>>List of violations.
Implementations