Module provider

Module provider 

Provider manager

Provider manager provides access to the individual service providers. This gives an easy interact for passing overall manager down to the individual providers that might need to call other providers while also allowing an easy injection of mocked providers.

Structs

Provider
Global provider manager.
ProviderBuilder
Builder for Provider.

Enums

ProviderBuilderError
Error type for ProviderBuilder