Module revoke

Module revoke 

Token revocation provider.

Token revocation may be implemented in different ways, but in most cases would be represented by the presence of the revocation or the invalidation record matching the certain token parameters.

Default backend is the sql and uses the database table for storing the revocation events. They have their own expiration.

Tokens are not invalidated by saving the exact value, but rather by saving certain attributes of the token.

Following attributes are used for matching of the regular fernet token:

  • audit_id
  • domain_id
  • expires_at
  • project_id
  • user_id

Additionally the token.issued_at is compared to be lower than the issued_before field of the revocation record.

Re-exports

pub use error::RevokeProviderError;
pub use types::*;

Modules

backend
Token revocation: Backends. Revocation provider Backend trait.
error
Token revocation errors.
service
Token revocation provider.
types
Token revocation types definitions. Revocation provider types.

Enums

RevokeProvider
Revoke provider.