RevokeBackend

Trait RevokeBackend 

pub trait RevokeBackend: Send + Sync {
    // Required methods
    fn create_revocation_event<'life0, 'life1, 'async_trait>(
        &'life0 self,
        state: &'life1 ServiceState,
        event: RevocationEventCreate,
    ) -> Pin<Box<dyn Future<Output = Result<RevocationEvent, RevokeProviderError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn is_token_revoked<'life0, 'life1, 'life2, 'async_trait>(
        &'life0 self,
        state: &'life1 ServiceState,
        token: &'life2 Token,
    ) -> Pin<Box<dyn Future<Output = Result<bool, RevokeProviderError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait;
    fn revoke_token<'life0, 'life1, 'life2, 'async_trait>(
        &'life0 self,
        state: &'life1 ServiceState,
        token: &'life2 Token,
    ) -> Pin<Box<dyn Future<Output = Result<(), RevokeProviderError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait;
}
RevokeBackend trait.

Backend driver interface expected by the revocation provider.

Required Methods

fn create_revocation_event<'life0, 'life1, 'async_trait>( &'life0 self, state: &'life1 ServiceState, event: RevocationEventCreate, ) -> Pin<Box<dyn Future<Output = Result<RevocationEvent, RevokeProviderError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Create revocation event.

fn is_token_revoked<'life0, 'life1, 'life2, 'async_trait>( &'life0 self, state: &'life1 ServiceState, token: &'life2 Token, ) -> Pin<Box<dyn Future<Output = Result<bool, RevokeProviderError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait,

Check token revocation.

Check whether there are existing revocation records that invalidate the token.

fn revoke_token<'life0, 'life1, 'life2, 'async_trait>( &'life0 self, state: &'life1 ServiceState, token: &'life2 Token, ) -> Pin<Box<dyn Future<Output = Result<(), RevokeProviderError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait,

Revoke the token.

Mark the token as revoked to prohibit from being used even while not expired.

Implementors