Module utils

Module utils 

Fernet utils

Structs

FernetUtils
Fernet utils.

Functions

read_audit_ids
Decode array of audit ids from the payload.
read_bin_data
Read binary data from the payload.
read_bool
Read boolean.
read_list_of_uuids
Decode array of strings ids from the payload.
read_str
Read bytes as string.
read_str_data
Read string data.
read_time
Read the time represented as a f64 of the UTC seconds.
read_uuid
Read the UUID from the payload. It is represented as an Array[bool, bytes] where first bool indicates whether following bytes are UUID or just bytes that should be treated as a string (for cases where ID is not a valid UUID).
write_audit_ids
Encode array of audit ids into the payload.
write_bool
Write boolean.
write_list_of_uuids
Encode array of bytes into the payload.
write_str
Write string.
write_time
Write the time represented as a f64 of the UTC seconds.
write_uuid
Write the UUID to the payload. It is represented as an Array[bool, bytes] where first bool indicates whether following bytes are UUID or just bytes that should be treated as a string (for cases where ID is not a valid UUID).