TokenProviderError

Enum TokenProviderError 

pub enum TokenProviderError {
Show 50 variants ActorHasNoRolesOnTarget, ApplicationCredentialExpired, ApplicationCredentialNotFound(String), ApplicationCredentialProvider { source: ApplicationCredentialProviderError, }, ApplicationCredentialScopeMismatch, AssignmentProvider { source: AssignmentProviderError, }, AuditIdWrongFormat, Authentication(AuthenticationError), Base64Decode(DecodeError), Conflict { message: String, context: String, }, DomainDisabled(String), Driver(String), Expired, ExpiryCalculation, FederatedPayloadMissingData, FernetDecryption(DecryptionError), FernetKeysMissing, FernetKeyRead { source: Error, path: PathBuf, }, IdentityProvider(IdentityProviderError), InvalidToken, InvalidTokenType(u8), InvalidTokenUuid, InvalidTokenUuidMarker(Marker), Io { source: Error, }, NixErrno { context: String, source: Errno, }, Persist(PersistError), ProjectDisabled(String), ResourceProvider(ResourceProviderError), RestrictedTokenNotProjectScoped, RevokeProvider(RevokeProviderError), RmpEncode(String), RmpValueRead(ValueReadError), RoleProvider { source: RoleProviderError, }, ScopeMissing, StructBuilder(BuilderError), SubjectMissing, TokenTimestampOverflow { value: u64, source: TryFromIntError, }, TokenRestrictionNotFound(String), TokenRevoked, TrustProvider(TrustProviderError), TrustorDomainDisabled, TryFromIntError(TryFromIntError), UnsupportedAuthMethods(String), UnsupportedTRDriver(String), UserDisabled(String), UserDomainDisabled, UserIsNotTrustee, UserNotFound(String), Uuid(Error), Validation(ValidationErrors),
}
Token provider error.

Variants



ActorHasNoRolesOnTarget

Actor has no roles on the target scope.



ApplicationCredentialExpired

Application Credential has expired.



ApplicationCredentialNotFound(String)

Application Credential used in the token is not found.



ApplicationCredentialProvider

Application credential provider error.

Fields

source: ApplicationCredentialProviderError

The source of the error.



ApplicationCredentialScopeMismatch

Application Credential is bound to the other project.



AssignmentProvider

Assignment provider error.

Fields

source: AssignmentProviderError

The source of the error.



AuditIdWrongFormat

AuditID must be urlsafe base64 encoded value.



Authentication(AuthenticationError)

Authentication error.



Base64Decode(DecodeError)

Base64 Decode error.



Conflict

Conflict.

Fields

message: String
context: String


DomainDisabled(String)

The domain is disabled.



Driver(String)

Driver error.



Expired

Expired token.



ExpiryCalculation

Expiry calculation error.



FederatedPayloadMissingData

Federated payload missing data error.



FernetDecryption(DecryptionError)

Fernet Decryption.



FernetKeysMissing

Missing fernet keys.



FernetKeyRead

Fernet key read error.

Fields

source: Error

The source of the error.

path: PathBuf

Key file name.



IdentityProvider(IdentityProviderError)

Identity provider error.



InvalidToken

Invalid token data.



InvalidTokenType(u8)

Unsupported token version.



InvalidTokenUuid

Unsupported token uuid.



InvalidTokenUuidMarker(Marker)

Unsupported token uuid coding.



Io

IO error.

Fields

source: Error

The source of the error.



NixErrno

Nix errno.

Fields

context: String

Context.

source: Errno

The source of the error.



Persist(PersistError)

tempfile persisting error.



ProjectDisabled(String)

The project is disabled.



ResourceProvider(ResourceProviderError)

Resource provider error.



RestrictedTokenNotProjectScoped

Restricted token project scoped error.



RevokeProvider(RevokeProviderError)

Revoke Provider error.



RmpEncode(String)

MSGPack Encryption.



RmpValueRead(ValueReadError)

MSGPack Decryption.



RoleProvider

Role provider error.

Fields

source: RoleProviderError

The source of the error.



ScopeMissing

Target scope information is not found in the token.



StructBuilder(BuilderError)

Structures builder error.



SubjectMissing

Target subject information is not found in the token.



TokenTimestampOverflow

Fernet payload timestamp overflow error.

Fields

value: u64

Token timestamp.

source: TryFromIntError

The source of the error.



TokenRestrictionNotFound(String)

Token restriction not found error.



TokenRevoked

Revoked token error.



TrustProvider(TrustProviderError)

Trust provider error.



TrustorDomainDisabled

The user domain of the trustee is disabled.



TryFromIntError(TryFromIntError)

Integer conversion error.



UnsupportedAuthMethods(String)

Unsupported authentication methods in token payload.



UnsupportedTRDriver(String)

Unsupported token restriction driver.



UserDisabled(String)

The user is disabled.



UserDomainDisabled

The user domain is disabled.



UserIsNotTrustee

The user is not trustee.



UserNotFound(String)

The user cannot be found error.



Uuid(Error)

UUID decryption error.



Validation(ValidationErrors)

Validation error.