TrustProviderError

Enum TrustProviderError 

pub enum TrustProviderError {
Show 14 variants AuthenticationInfo { source: AuthenticationError, }, Conflict(String), Driver(String), ExpirationImpossible, ExpirationDateTimeParse { id: String, expires_at: i64, }, RedelegatedImpersonationNotAllowed, RedelegatedRolesNotAvailable, RedelegationDeepnessExceed { length: usize, max_depth: usize, }, RemainingUsesExceed, RemainingUsesMustBeUnset, RoleProvider { source: RoleProviderError, }, Serde { source: Error, }, StructBuilder { source: BuilderError, }, UnsupportedDriver(String),
}
Trust extension error.

Variants



AuthenticationInfo

Supported authentication error.

Fields

source: AuthenticationError

The source of the error.



Conflict(String)

Conflict.



Driver(String)

Driver error.



ExpirationImpossible

Trust expiration is more than the redelegated trust can provide.



ExpirationDateTimeParse

DateTime parsing error.

Fields

expires_at: i64


RedelegatedImpersonationNotAllowed

Relegated trust does not allow impersonation.



RedelegatedRolesNotAvailable

Relegation trust must not add new roles.



RedelegationDeepnessExceed

Redelegation chain is longer than allowed.

Fields

length: usize
max_depth: usize


RemainingUsesExceed

Remaining uses of the trust is exceeded.



RemainingUsesMustBeUnset

Remaining uses must be unset to redelegate a trust.



RoleProvider

Role provider error.

Fields

source: RoleProviderError

The source of the error.



Serde

(de)serialization error.

Fields

source: Error

The source of the error.



StructBuilder

Structures builder error.

Fields

source: BuilderError

The source of the error.



UnsupportedDriver(String)

Unsupported driver.