pub struct User {
pub default_project_id: Option<String>,
pub domain_id: String,
pub enabled: bool,
pub extra: Option<Value>,
pub federated: Option<Vec<Federation>>,
pub id: String,
pub name: String,
pub options: Option<UserOptions>,
pub password_expires_at: Option<DateTime<Utc>>,
}Expand description
User response object.
Fields
default_project_id: Option<String>The ID of the default project for the user. A user’s default project must not be a domain. Setting this attribute does not grant any actual authorization on the project, and is merely provided for convenience. Therefore, the referenced project does not need to exist within the user domain. If the user does not have authorization to their default project, the default project is ignored at token creation. Additionally, if your default project is not valid, a token is issued without an explicit scope of authorization.
domain_id: StringUser domain ID.
enabled: boolIf the user is enabled, this value is true. If the user is disabled, this value is false.
extra: Option<Value>federated: Option<Vec<Federation>>List of federated objects associated with a user. Each object in the list contains the idp_id and protocols. protocols is a list of objects, each of which contains protocol_id and unique_id of the protocol and user respectively.
id: StringUser ID.
name: StringUser name.
options: Option<UserOptions>The resource options for the user. Available resource options are ignore_change_password_upon_first_use, ignore_password_expiry, ignore_lockout_failure_attempts, lock_password, multi_factor_auth_enabled, and multi_factor_auth_rules ignore_user_inactivity.
password_expires_at: Option<DateTime<Utc>>The date and time when the password expires. The time zone is UTC.