pub struct UserBuilder { /* private fields */ }Expand description
Builder for User.
Implementations
Sourceimpl UserBuilder
impl UserBuilder
Sourcepub fn default_project_id<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
pub fn default_project_id<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
The ID of the default project for the user. A user’s default project must not be a domain. Setting this attribute does not grant any actual authorization on the project, and is merely provided for convenience. Therefore, the referenced project does not need to exist within the user domain. If the user does not have authorization to their default project, the default project is ignored at token creation. Additionally, if your default project is not valid, a token is issued without an explicit scope of authorization.
Sourcepub fn domain_id<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
pub fn domain_id<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
User domain ID.
Sourcepub fn enabled<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
pub fn enabled<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
If the user is enabled, this value is true. If the user is disabled, this value is false.
pub fn extra<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
Sourcepub fn federated<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
pub fn federated<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
List of federated objects associated with a user. Each object in the list contains the idp_id and protocols. protocols is a list of objects, each of which contains protocol_id and unique_id of the protocol and user respectively.
Sourcepub fn id<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
pub fn id<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
User ID.
Sourcepub fn name<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
pub fn name<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
User name.
Sourcepub fn options<VALUE>(&mut self, value: VALUE) -> &mut UserBuilderwhere
VALUE: Into<UserOptions>,
pub fn options<VALUE>(&mut self, value: VALUE) -> &mut UserBuilderwhere
VALUE: Into<UserOptions>,
The resource options for the user. Available resource options are ignore_change_password_upon_first_use, ignore_password_expiry, ignore_lockout_failure_attempts, lock_password, multi_factor_auth_enabled, and multi_factor_auth_rules ignore_user_inactivity.
Sourcepub fn password_expires_at<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
pub fn password_expires_at<VALUE>(&mut self, value: VALUE) -> &mut UserBuilder
The date and time when the password expires. The time zone is UTC.