Module auth

Module auth 

Authorization and authentication information.

Authentication and authorization types with corresponding validation. Authentication specific validation may stay in the corresponding provider (i.e. user password is expired), but general validation rules must be present here to be shared across different authentication methods. The same is valid for the authorization validation (project/domain must exist and be enabled).

Structs

AuthenticatedInfo
Information about successful authentication.
AuthenticatedInfoBuilder
Builder for AuthenticatedInfo.

Enums

AuthenticationError
AuthzInfo
Authorization information.