Read the UUID from the payload.
It is represented as an Array[bool, bytes] where first bool indicates
whether following bytes are UUID or just bytes that should be treated as a
string (for cases where ID is not a valid UUID).
Write the UUID to the payload.
It is represented as an Array[bool, bytes] where first bool indicates
whether following bytes are UUID or just bytes that should be treated as a
string (for cases where ID is not a valid UUID).