Token provider.
A Keystone token is an alpha-numeric text string that enables access to OpenStack APIs and resources. A token may be revoked at any time and is valid for a finite duration. OpenStack Identity is an integration service that does not aspire to be a full-fledged identity store and management solution.
Re-exports
pub use crate::token::types::*;